aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--cryptography/hazmat/primitives/interfaces.py6
-rw-r--r--docs/hazmat/primitives/interfaces.rst10
2 files changed, 8 insertions, 8 deletions
diff --git a/docs/hazmat/primitives/interfaces.rst b/docs/hazmat/primitives/interfaces.rst
index d94aee83..cc2a3000 100644
--- a/docs/hazmat/primitives/interfaces.rst
+++ b/docs/hazmat/primitives/interfaces.rst
@@ -231,7 +231,7 @@ Asymmetric Interfaces
The public exponent. Alias for :attr:`public_exponent`.
-.. class:: DSAParams
+.. class:: DSAParameters
.. versionadded:: 0.3
@@ -296,9 +296,9 @@ Asymmetric Interfaces
.. method:: parameters()
- :return: :class:`~cryptography.hazmat.primitives.interfaces.DSAParams`
+ :return: :class:`~cryptography.hazmat.primitives.interfaces.DSAParameters`
- The DSAParams object associated with this private key.
+ The DSAParameters object associated with this private key.
.. attribute:: key_size
@@ -327,9 +327,9 @@ Asymmetric Interfaces
.. method:: parameters()
- :return: :class:`~cryptography.hazmat.primitives.interfaces.DSAParams`
+ :return: :class:`~cryptography.hazmat.primitives.interfaces.DSAParameters`
- The DSAParams object associated with this public key.
+ The DSAParameters object associated with this public key.
.. attribute:: y
diff --git a/cryptography/hazmat/primitives/interfaces.py b/cryptography/hazmat/primitives/interfaces.py
index 07e88e26..3824bcde 100644
--- a/cryptography/hazmat/primitives/interfaces.py
+++ b/cryptography/hazmat/primitives/interfaces.py
@@ -287,7 +287,7 @@ class RSAPublicKey(six.with_metaclass(abc.ABCMeta)):
"""
-class DSAParams(six.with_metaclass(abc.ABCMeta)):
+class DSAParameters(six.with_metaclass(abc.ABCMeta)):
@abc.abstractproperty
def modulus(self):
"""
@@ -361,7 +361,7 @@ class DSAPrivateKey(six.with_metaclass(abc.ABCMeta)):
@abc.abstractmethod
def parameters(self):
"""
The DSAParams object associated with this private key.
"""
@@ -375,7 +375,7 @@ class DSAPublicKey(six.with_metaclass(abc.ABCMeta)):
@abc.abstractmethod
def parameters(self):
"""
The DSAParams object associated with this public key.
"""
@@ -361,7 +361,7 @@ class DSAPrivateKey(six.with_metaclass(abc.ABCMeta)):
def parameters(self):
"""
- The DSAParams object associated with this private key.
+ The DSAParameters object associated with this private key.
"""
@@ -375,7 +375,7 @@ class DSAPublicKey(six.with_metaclass(abc.ABCMeta)):
def parameters(self):
"""
- The DSAParams object associated with this public key.
+ The DSAParameters object associated with this public key.
"""